@@ -8,20 +8,20 @@ __all__ = ['Interval','I','Logical']
 
 class Interval:
     """
-    Interval
-    ---------
     An interval is an uncertain number for which only the endpoints are known, for example if :math:`x=[a,b]`
     then this can be interpreted as :math:`x` being between :math:`a` and :math:`b` but with no more information about the value of :math:`x`
     .
     Intervals can be created using::
         pba.I(left,right)
         pba.Interval(left,right)
+        
     Parameters
     ----------
     left : numeric
         left side of interval
     right : numeric
         right side of interval
+        
     Attributes
     ----------
     left : numeric
@@ -214,7 +214,11 @@ class Interval:
 
                 lo = min(b1,b2,b3,b4)
                 hi = max(b1,b2,b3,b4)
+                
+        elif other.__class__.__name__ == "Pbox":
 
+            return other.__rtruediv__(self)
+        
         else:
             try:
                 lo = self.lo()/other
@@ -604,6 +608,13 @@ class Interval:
         lo = np.exp(self.left)
         hi = np.exp(self.right)
         return Interval(lo,hi)
+    
+    def sqrt(self):
+        if self.left >= 0:
+            return Interval(np.sqrt(self.left),np.sqrt(self.right))
+        else:
+            print("RuntimeWarning: invalid value encountered in sqrt")
+            return Interval(np.nan,np.sqrt(self.right))
 # a = Interval(1,2)
 # b = Interval(3,4)
 # c = Interval(-2,5)
